Transform2D

Struct Transform2D 

pub struct Transform2D { /* private fields */ }
Combined x and y axis transforms for a 2D plotting area.

Implementations

Source

impl Transform2D

pub const fn new(x: AxisTransform, y: AxisTransform) -> Self

Creates a 2D transform from separate x and y axis transforms.

pub const fn x(self) -> AxisTransform

Returns the x-axis transform.

pub const fn y(self) -> AxisTransform

Returns the y-axis transform.

pub fn data_to_pixel_x(self, x: f64) -> Option<i32>

Converts a data-space x value to a pixel x coordinate.

pub fn data_to_pixel_y(self, y: f64) -> Option<i32>

Converts a data-space y value to a pixel y coordinate.