#[non_exhaustive]pub enum BarplotError {
LengthMismatch,
NegativeValuesUnsupported,
InvalidNumericValue {
value: String,
},
EmptyAppend,
UnknownBorderType {
name: String,
},
}Expand description
Errors returned by barplot construction and mutation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LengthMismatch
Labels and values slices have different lengths.
NegativeValuesUnsupported
A bar value is negative (only non-negative values are supported).
InvalidNumericValue
A value could not be parsed as a finite floating-point number.
EmptyAppend
Attempted to append an empty label/value set.
UnknownBorderType
The border name string does not match any known border type.