#[non_exhaustive]pub enum BoxplotError {
LengthMismatch,
EmptySeries,
EmptyAppend,
InvalidXLimits,
InvalidNumericValue {
value: String,
},
}Expand description
Errors returned by boxplot construction and mutation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LengthMismatch
Labels and series counts do not match.
EmptySeries
No series provided, or a series contains no valid data.
EmptyAppend
Attempted to append an empty data set.
InvalidXLimits
Explicit x limits are non-finite or inverted.
InvalidNumericValue
A data value could not be parsed as a finite number.