GridCanvas

Enum GridCanvas 

#[non_exhaustive]
pub enum GridCanvas { Ascii(AsciiCanvas), Block(BlockCanvas), Braille(BrailleCanvas), Density(DensityCanvas), Dot(DotCanvas), }
A runtime-selected canvas backend for line, scatter, and density plots.

Wraps all five canvas types behind a single enum so that plots can select the canvas at runtime via CanvasType.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.