pub struct Transform2D { /* private fields */ }Expand description
Combined x and y axis transforms for a 2D plotting area.
Implementations
Sourceimpl Transform2D
impl Transform2D
Sourcepub const fn new(x: AxisTransform, y: AxisTransform) -> Self
pub const fn new(x: AxisTransform, y: AxisTransform) -> Self
Creates a 2D transform from separate x and y axis transforms.
Sourcepub const fn x(self) -> AxisTransform
pub const fn x(self) -> AxisTransform
Returns the x-axis transform.
Sourcepub const fn y(self) -> AxisTransform
pub const fn y(self) -> AxisTransform
Returns the y-axis transform.
Sourcepub fn data_to_pixel_x(self, x: f64) -> Option<i32>
pub fn data_to_pixel_x(self, x: f64) -> Option<i32>
Converts a data-space x value to a pixel x coordinate.
Sourcepub fn data_to_pixel_y(self, y: f64) -> Option<i32>
pub fn data_to_pixel_y(self, y: f64) -> Option<i32>
Converts a data-space y value to a pixel y coordinate.