#[non_exhaustive]pub enum StairStyle {
Pre,
Post,
}Expand description
Step direction for staircase plots.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pre
Step transition occurs at the start of each interval.
Post
Step transition occurs at the end of each interval (default).